AnalyticsHubService

Struct AnalyticsHubService 

pub struct AnalyticsHubService { /* private fields */ }
Implements a client for the Analytics Hub API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = AnalyticsHubService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_data_exchanges()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

The AnalyticsHubService API facilitates data sharing within and across organizations. It allows data providers to publish listings that reference shared datasets. With Analytics Hub, users can discover and search for listings that they have access to. Subscribers can view and subscribe to listings. When you subscribe to a listing, Analytics Hub creates a linked dataset in your project.

Configuration

To configure AnalyticsHubService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://analyticshub.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

AnalyticsHubService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap AnalyticsHubService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl AnalyticsHubService

pub fn builder() -> ClientBuilder

Returns a builder for AnalyticsHubService.

let client = AnalyticsHubService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: AnalyticsHubService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_data_exchanges(&self) -> ListDataExchanges

Lists all data exchanges in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, parent: &str
) -> Result<()> {
    let mut list = client.list_data_exchanges()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_org_data_exchanges(&self) -> ListOrgDataExchanges

Lists all data exchanges from projects in a given organization and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let mut list = client.list_org_data_exchanges()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_data_exchange(&self) -> GetDataExchange

Gets the details of a data exchange.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    let response = client.get_data_exchange()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_data_exchange(&self) -> CreateDataExchange

Creates a new data exchange.

Example
use google_cloud_bigquery_analyticshub_v1::model::DataExchange;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, parent: &str
) -> Result<()> {
    let response = client.create_data_exchange()
        .set_parent(parent)
        .set_data_exchange(
            DataExchange::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_data_exchange(&self) -> UpdateDataExchange

Updates an existing data exchange.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_bigquery_analyticshub_v1::model::DataExchange;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    let response = client.update_data_exchange()
        .set_data_exchange(
            DataExchange::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_data_exchange(&self) -> DeleteDataExchange

Deletes an existing data exchange.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    client.delete_data_exchange()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn list_listings(&self) -> ListListings

Lists all listings in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, parent: &str
) -> Result<()> {
    let mut list = client.list_listings()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_listing(&self) -> GetListing

Gets the details of a listing.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    let response = client.get_listing()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_listing(&self) -> CreateListing

Creates a new listing.

Example
use google_cloud_bigquery_analyticshub_v1::model::Listing;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, parent: &str
) -> Result<()> {
    let response = client.create_listing()
        .set_parent(parent)
        .set_listing_id("listing_id_value")
        .set_listing(
            Listing::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_listing(&self) -> UpdateListing

Updates an existing listing.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_bigquery_analyticshub_v1::model::Listing;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    let response = client.update_listing()
        .set_listing(
            Listing::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_listing(&self) -> DeleteListing

Deletes a listing.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    client.delete_listing()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn subscribe_listing(&self) -> SubscribeListing

Subscribes to a listing.

Currently, with Analytics Hub, you can create listings that reference only BigQuery datasets. Upon subscription to a listing for a BigQuery dataset, Analytics Hub creates a linked dataset in the subscriber’s project.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.subscribe_listing()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn subscribe_data_exchange(&self) -> SubscribeDataExchange

Creates a Subscription to a Data Clean Room. This is a long-running operation as it will create one or more linked datasets. Throws a Bad Request error if the Data Exchange does not contain any listings.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.subscribe_data_exchange()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn refresh_subscription(&self) -> RefreshSubscription

Refreshes a Subscription to a Data Exchange. A Data Exchange can become stale when a publisher adds or removes data. This is a long-running operation as it may create many linked datasets.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.refresh_subscription()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_subscription(&self) -> GetSubscription

Gets the details of a Subscription.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    let response = client.get_subscription()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_subscriptions(&self) -> ListSubscriptions

Lists all subscriptions in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, parent: &str
) -> Result<()> {
    let mut list = client.list_subscriptions()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_shared_resource_subscriptions( &self, ) -> ListSharedResourceSubscriptions

Lists all subscriptions on a given Data Exchange or Listing.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let mut list = client.list_shared_resource_subscriptions()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn revoke_subscription(&self) -> RevokeSubscription

Revokes a given subscription.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.revoke_subscription()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_subscription(&self) -> DeleteSubscription

Deletes a subscription.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    client.delete_subscription()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the IAM policy.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the IAM policy.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns the permissions that a caller has.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_query_template(&self) -> CreateQueryTemplate

Creates a new QueryTemplate

Example
use google_cloud_bigquery_analyticshub_v1::model::QueryTemplate;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, parent: &str
) -> Result<()> {
    let response = client.create_query_template()
        .set_parent(parent)
        .set_query_template(
            QueryTemplate::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_query_template(&self) -> GetQueryTemplate

Gets a QueryTemplate

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    let response = client.get_query_template()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_query_templates(&self) -> ListQueryTemplates

Lists all QueryTemplates in a given project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, parent: &str
) -> Result<()> {
    let mut list = client.list_query_templates()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn update_query_template(&self) -> UpdateQueryTemplate

Updates an existing QueryTemplate

Example
use google_cloud_wkt::FieldMask;
use google_cloud_bigquery_analyticshub_v1::model::QueryTemplate;
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    let response = client.update_query_template()
        .set_query_template(
            QueryTemplate::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_query_template(&self) -> DeleteQueryTemplate

Deletes a query template.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService, name: &str
) -> Result<()> {
    client.delete_query_template()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn submit_query_template(&self) -> SubmitQueryTemplate

Submits a query template for approval.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.submit_query_template()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn approve_query_template(&self) -> ApproveQueryTemplate

Approves a query template.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.approve_query_template()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_bigquery_analyticshub_v1::Result;
async fn sample(
   client: &AnalyticsHubService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}