#[non_exhaustive]pub struct BigQueryDatasetSource {
pub dataset: String,
pub selected_resources: Vec<SelectedResource>,
pub restricted_export_policy: Option<RestrictedExportPolicy>,
pub replica_locations: Vec<String>,
pub effective_replicas: Vec<Replica>,
/* private fields */
}Expand description
A reference to a shared dataset. It is an existing BigQuery dataset with a collection of objects such as tables and views that you want to share with subscribers. When subscriber’s subscribe to a listing, Analytics Hub creates a linked dataset in the subscriber’s project. A Linked dataset is an opaque, read-only BigQuery dataset that serves as a symbolic link to a shared dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dataset: StringOptional. Resource name of the dataset source for this listing.
e.g. projects/myproject/datasets/123
selected_resources: Vec<SelectedResource>Optional. Resource in this dataset that is selectively shared. This field is required for data clean room exchanges.
restricted_export_policy: Option<RestrictedExportPolicy>Optional. If set, restricted export policy will be propagated and enforced on the linked dataset.
replica_locations: Vec<String>Optional. A list of regions where the publisher has created shared dataset replicas.
effective_replicas: Vec<Replica>Output only. Server-owned effective state of replicas. Contains both primary and secondary replicas. Each replica includes a system-computed (output-only) state and primary designation.
Implementations
Sourceimpl BigQueryDatasetSource
impl BigQueryDatasetSource
Sourcepub fn set_dataset<T: Into<String>>(self, v: T) -> Self
pub fn set_dataset<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_selected_resources<T, V>(self, v: T) -> Self
pub fn set_selected_resources<T, V>(self, v: T) -> Self
Sets the value of selected_resources.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::SelectedResource;
let x = BigQueryDatasetSource::new()
.set_selected_resources([
SelectedResource::default()/* use setters */,
SelectedResource::default()/* use (different) setters */,
]);Sourcepub fn set_restricted_export_policy<T>(self, v: T) -> Selfwhere
T: Into<RestrictedExportPolicy>,
pub fn set_restricted_export_policy<T>(self, v: T) -> Selfwhere
T: Into<RestrictedExportPolicy>,
Sets the value of restricted_export_policy.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::RestrictedExportPolicy;
let x = BigQueryDatasetSource::new().set_restricted_export_policy(RestrictedExportPolicy::default()/* use setters */);Sourcepub fn set_or_clear_restricted_export_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictedExportPolicy>,
pub fn set_or_clear_restricted_export_policy<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictedExportPolicy>,
Sets or clears the value of restricted_export_policy.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::RestrictedExportPolicy;
let x = BigQueryDatasetSource::new().set_or_clear_restricted_export_policy(Some(RestrictedExportPolicy::default()/* use setters */));
let x = BigQueryDatasetSource::new().set_or_clear_restricted_export_policy(None::<RestrictedExportPolicy>);Sourcepub fn set_replica_locations<T, V>(self, v: T) -> Self
pub fn set_replica_locations<T, V>(self, v: T) -> Self
Sets the value of replica_locations.
Example
let x = BigQueryDatasetSource::new().set_replica_locations(["a", "b", "c"]);Sourcepub fn set_effective_replicas<T, V>(self, v: T) -> Self
pub fn set_effective_replicas<T, V>(self, v: T) -> Self
Sets the value of effective_replicas.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::Replica;
let x = BigQueryDatasetSource::new()
.set_effective_replicas([
Replica::default()/* use setters */,
Replica::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for BigQueryDatasetSource
impl Clone for BigQueryDatasetSource
Sourcefn clone(&self) -> BigQueryDatasetSource
fn clone(&self) -> BigQueryDatasetSource
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BigQueryDatasetSource
impl Debug for BigQueryDatasetSource
Sourceimpl Default for BigQueryDatasetSource
impl Default for BigQueryDatasetSource
Sourcefn default() -> BigQueryDatasetSource
fn default() -> BigQueryDatasetSource
Sourceimpl Message for BigQueryDatasetSource
impl Message for BigQueryDatasetSource
Sourceimpl PartialEq for BigQueryDatasetSource
impl PartialEq for BigQueryDatasetSource
impl StructuralPartialEq for BigQueryDatasetSource