#[non_exhaustive]pub struct RestrictedExportConfig {
pub enabled: bool,
pub restrict_direct_table_access: bool,
pub restrict_query_result: bool,
/* private fields */
}Expand description
Restricted export config, used to configure restricted export on linked dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolOptional. If true, enable restricted export.
restrict_direct_table_access: boolOutput only. If true, restrict direct table access(read api/tabledata.list) on linked table.
restrict_query_result: boolOptional. If true, restrict export of query result derived from restricted linked dataset table.
Implementations
Sourceimpl RestrictedExportConfig
impl RestrictedExportConfig
pub fn new() -> Self
Sourcepub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_restrict_direct_table_access<T: Into<bool>>(self, v: T) -> Self
pub fn set_restrict_direct_table_access<T: Into<bool>>(self, v: T) -> Self
Sets the value of restrict_direct_table_access.
Example
ⓘ
let x = RestrictedExportConfig::new().set_restrict_direct_table_access(true);Sourcepub fn set_restrict_query_result<T: Into<bool>>(self, v: T) -> Self
pub fn set_restrict_query_result<T: Into<bool>>(self, v: T) -> Self
Sets the value of restrict_query_result.
Example
ⓘ
let x = RestrictedExportConfig::new().set_restrict_query_result(true);Trait Implementations
Sourceimpl Clone for RestrictedExportConfig
impl Clone for RestrictedExportConfig
Sourcefn clone(&self) -> RestrictedExportConfig
fn clone(&self) -> RestrictedExportConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RestrictedExportConfig
impl Debug for RestrictedExportConfig
Sourceimpl Default for RestrictedExportConfig
impl Default for RestrictedExportConfig
Sourcefn default() -> RestrictedExportConfig
fn default() -> RestrictedExportConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for RestrictedExportConfig
impl Message for RestrictedExportConfig
Sourceimpl PartialEq for RestrictedExportConfig
impl PartialEq for RestrictedExportConfig
impl StructuralPartialEq for RestrictedExportConfig