#[non_exhaustive]pub struct DataExchange {
pub name: String,
pub display_name: String,
pub description: String,
pub primary_contact: String,
pub documentation: String,
pub listing_count: i32,
pub icon: Bytes,
pub sharing_environment_config: Option<SharingEnvironmentConfig>,
pub discovery_type: Option<DiscoveryType>,
pub log_linked_dataset_query_user_email: Option<bool>,
/* private fields */
}Expand description
A data exchange is a container that lets you share data. Along with the descriptive information about the data exchange, it contains listings that reference shared datasets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the data exchange.
e.g. projects/myproject/locations/us/dataExchanges/123.
display_name: StringRequired. Human-readable display name of the data exchange. The display name must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-), spaces ( ), ampersands (&) and must not start or end with spaces. Default value is an empty string. Max length: 63 bytes.
description: StringOptional. Description of the data exchange. The description must not contain Unicode non-characters as well as C0 and C1 control codes except tabs (HT), new lines (LF), carriage returns (CR), and page breaks (FF). Default value is an empty string. Max length: 2000 bytes.
primary_contact: StringOptional. Email or URL of the primary point of contact of the data exchange. Max Length: 1000 bytes.
documentation: StringOptional. Documentation describing the data exchange.
listing_count: i32Output only. Number of listings contained in the data exchange.
icon: BytesOptional. Base64 encoded image representing the data exchange. Max Size: 3.0MiB Expected image dimensions are 512x512 pixels, however the API only performs validation on size of the encoded data. Note: For byte fields, the content of the fields are base64-encoded (which increases the size of the data by 33-36%) when using JSON on the wire.
sharing_environment_config: Option<SharingEnvironmentConfig>Optional. Configurable data sharing environment option for a data exchange.
discovery_type: Option<DiscoveryType>Optional. Type of discovery on the discovery page for all the listings under this exchange. Updating this field also updates (overwrites) the discovery_type field for all the listings under this exchange.
log_linked_dataset_query_user_email: Option<bool>Optional. By default, false. If true, the DataExchange has an email sharing mandate enabled.
Implementations
Sourceimpl DataExchange
impl DataExchange
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_primary_contact<T: Into<String>>(self, v: T) -> Self
pub fn set_primary_contact<T: Into<String>>(self, v: T) -> Self
Sets the value of primary_contact.
Example
let x = DataExchange::new().set_primary_contact("example");Sourcepub fn set_documentation<T: Into<String>>(self, v: T) -> Self
pub fn set_documentation<T: Into<String>>(self, v: T) -> Self
Sets the value of documentation.
Example
let x = DataExchange::new().set_documentation("example");Sourcepub fn set_listing_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_listing_count<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_sharing_environment_config<T>(self, v: T) -> Selfwhere
T: Into<SharingEnvironmentConfig>,
pub fn set_sharing_environment_config<T>(self, v: T) -> Selfwhere
T: Into<SharingEnvironmentConfig>,
Sets the value of sharing_environment_config.
Example
use google_cloud_bigquery_analyticshub_v1::model::SharingEnvironmentConfig;
let x = DataExchange::new().set_sharing_environment_config(SharingEnvironmentConfig::default()/* use setters */);Sourcepub fn set_or_clear_sharing_environment_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SharingEnvironmentConfig>,
pub fn set_or_clear_sharing_environment_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SharingEnvironmentConfig>,
Sets or clears the value of sharing_environment_config.
Example
use google_cloud_bigquery_analyticshub_v1::model::SharingEnvironmentConfig;
let x = DataExchange::new().set_or_clear_sharing_environment_config(Some(SharingEnvironmentConfig::default()/* use setters */));
let x = DataExchange::new().set_or_clear_sharing_environment_config(None::<SharingEnvironmentConfig>);Sourcepub fn set_discovery_type<T>(self, v: T) -> Selfwhere
T: Into<DiscoveryType>,
pub fn set_discovery_type<T>(self, v: T) -> Selfwhere
T: Into<DiscoveryType>,
Sets the value of discovery_type.
Example
use google_cloud_bigquery_analyticshub_v1::model::DiscoveryType;
let x0 = DataExchange::new().set_discovery_type(DiscoveryType::Private);
let x1 = DataExchange::new().set_discovery_type(DiscoveryType::Public);Sourcepub fn set_or_clear_discovery_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoveryType>,
pub fn set_or_clear_discovery_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoveryType>,
Sets or clears the value of discovery_type.
Example
use google_cloud_bigquery_analyticshub_v1::model::DiscoveryType;
let x0 = DataExchange::new().set_or_clear_discovery_type(Some(DiscoveryType::Private));
let x1 = DataExchange::new().set_or_clear_discovery_type(Some(DiscoveryType::Public));
let x_none = DataExchange::new().set_or_clear_discovery_type(None::<DiscoveryType>);Sourcepub fn set_log_linked_dataset_query_user_email<T>(self, v: T) -> Self
pub fn set_log_linked_dataset_query_user_email<T>(self, v: T) -> Self
Sets the value of log_linked_dataset_query_user_email.
Example
let x = DataExchange::new().set_log_linked_dataset_query_user_email(true);Sourcepub fn set_or_clear_log_linked_dataset_query_user_email<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_log_linked_dataset_query_user_email<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of log_linked_dataset_query_user_email.
Example
let x = DataExchange::new().set_or_clear_log_linked_dataset_query_user_email(Some(false));
let x = DataExchange::new().set_or_clear_log_linked_dataset_query_user_email(None::<bool>);Trait Implementations
Sourceimpl Clone for DataExchange
impl Clone for DataExchange
Sourcefn clone(&self) -> DataExchange
fn clone(&self) -> DataExchange
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataExchange
impl Debug for DataExchange
Sourceimpl Default for DataExchange
impl Default for DataExchange
Sourcefn default() -> DataExchange
fn default() -> DataExchange
Sourceimpl Message for DataExchange
impl Message for DataExchange
Sourceimpl PartialEq for DataExchange
impl PartialEq for DataExchange
impl StructuralPartialEq for DataExchange