#[non_exhaustive]pub struct DestinationDataset {
pub dataset_reference: Option<DestinationDatasetReference>,
pub friendly_name: Option<StringValue>,
pub description: Option<StringValue>,
pub labels: HashMap<String, String>,
pub location: String,
pub replica_locations: Vec<String>,
/* private fields */
}Expand description
Defines the destination bigquery dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dataset_reference: Option<DestinationDatasetReference>Required. A reference that identifies the destination dataset.
friendly_name: Option<StringValue>Optional. A descriptive name for the dataset.
description: Option<StringValue>Optional. A user-friendly description of the dataset.
labels: HashMap<String, String>Optional. The labels associated with this dataset. You can use these to organize and group your datasets. You can set this property when inserting or updating a dataset. See https://cloud.google.com/resource-manager/docs/creating-managing-labels for more information.
location: StringRequired. The geographic location where the dataset should reside. See https://cloud.google.com/bigquery/docs/locations for supported locations.
replica_locations: Vec<String>Optional. The geographic locations where the dataset should be replicated. See BigQuery locations for supported locations.
Implementations
Sourceimpl DestinationDataset
impl DestinationDataset
Sourcepub fn set_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<DestinationDatasetReference>,
pub fn set_dataset_reference<T>(self, v: T) -> Selfwhere
T: Into<DestinationDatasetReference>,
Sets the value of dataset_reference.
Example
use google_cloud_bigquery_analyticshub_v1::model::DestinationDatasetReference;
let x = DestinationDataset::new().set_dataset_reference(DestinationDatasetReference::default()/* use setters */);Sourcepub fn set_or_clear_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<DestinationDatasetReference>,
pub fn set_or_clear_dataset_reference<T>(self, v: Option<T>) -> Selfwhere
T: Into<DestinationDatasetReference>,
Sets or clears the value of dataset_reference.
Example
use google_cloud_bigquery_analyticshub_v1::model::DestinationDatasetReference;
let x = DestinationDataset::new().set_or_clear_dataset_reference(Some(DestinationDatasetReference::default()/* use setters */));
let x = DestinationDataset::new().set_or_clear_dataset_reference(None::<DestinationDatasetReference>);Sourcepub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_friendly_name<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of friendly_name.
Example
use wkt::StringValue;
let x = DestinationDataset::new().set_friendly_name(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_friendly_name<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of friendly_name.
Example
use wkt::StringValue;
let x = DestinationDataset::new().set_or_clear_friendly_name(Some(StringValue::default()/* use setters */));
let x = DestinationDataset::new().set_or_clear_friendly_name(None::<StringValue>);Sourcepub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
pub fn set_description<T>(self, v: T) -> Selfwhere
T: Into<StringValue>,
Sets the value of description.
Example
use wkt::StringValue;
let x = DestinationDataset::new().set_description(StringValue::default()/* use setters */);Sourcepub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
pub fn set_or_clear_description<T>(self, v: Option<T>) -> Selfwhere
T: Into<StringValue>,
Sets or clears the value of description.
Example
use wkt::StringValue;
let x = DestinationDataset::new().set_or_clear_description(Some(StringValue::default()/* use setters */));
let x = DestinationDataset::new().set_or_clear_description(None::<StringValue>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_replica_locations<T, V>(self, v: T) -> Self
pub fn set_replica_locations<T, V>(self, v: T) -> Self
Sets the value of replica_locations.
Example
let x = DestinationDataset::new().set_replica_locations(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for DestinationDataset
impl Clone for DestinationDataset
Sourcefn clone(&self) -> DestinationDataset
fn clone(&self) -> DestinationDataset
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DestinationDataset
impl Debug for DestinationDataset
Sourceimpl Default for DestinationDataset
impl Default for DestinationDataset
Sourcefn default() -> DestinationDataset
fn default() -> DestinationDataset
Sourceimpl Message for DestinationDataset
impl Message for DestinationDataset
Sourceimpl PartialEq for DestinationDataset
impl PartialEq for DestinationDataset
impl StructuralPartialEq for DestinationDataset