ListSubscriptionsRequest

Struct ListSubscriptionsRequest 

#[non_exhaustive]
pub struct ListSubscriptionsRequest { pub parent: String, pub filter: String, pub page_size: i32, pub page_token: String, /* private fields */ }
Message for listing subscriptions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent resource path of the subscription. e.g. projects/myproject/locations/us

filter: String

An expression for filtering the results of the request. Eligible fields for filtering are:

  • listing
  • data_exchange

Alternatively, a literal wrapped in double quotes may be provided. This will be checked for an exact match against both fields above.

In all cases, the full Data Exchange or Listing resource name must be provided. Some example of using filters:

  • data_exchange=“projects/myproject/locations/us/dataExchanges/123”
  • listing=“projects/123/locations/us/dataExchanges/456/listings/789”
  • “projects/myproject/locations/us/dataExchanges/123”
page_size: i32

The maximum number of results to return in a single response page.

page_token: String

Page token, returned by a previous call.

Implementations

Source

impl ListSubscriptionsRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListSubscriptionsRequest::new().set_parent("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListSubscriptionsRequest::new().set_filter("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListSubscriptionsRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListSubscriptionsRequest::new().set_page_token("example");