#[non_exhaustive]pub struct QueryTemplate {
pub name: String,
pub display_name: String,
pub description: String,
pub proposer: String,
pub primary_contact: String,
pub documentation: String,
pub state: State,
pub routine: Option<Routine>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
A query template is a container for sharing table-valued functions defined by contributors in a data clean room.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the QueryTemplate.
e.g. projects/myproject/locations/us/dataExchanges/123/queryTemplates/456
display_name: StringRequired. Human-readable display name of the QueryTemplate. The display name must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-), spaces ( ), ampersands (&) and can’t start or end with spaces. Default value is an empty string. Max length: 63 bytes.
description: StringOptional. Short description of the QueryTemplate. The description must not contain Unicode non-characters and C0 and C1 control codes except tabs (HT), new lines (LF), carriage returns (CR), and page breaks (FF). Default value is an empty string. Max length: 2000 bytes.
proposer: StringOptional. Will be deprecated. Email or URL of the primary point of contact of the QueryTemplate. Max Length: 1000 bytes.
primary_contact: StringOptional. Email or URL of the primary point of contact of the QueryTemplate. Max Length: 1000 bytes.
documentation: StringOptional. Documentation describing the QueryTemplate.
state: StateOutput only. The QueryTemplate lifecycle state.
routine: Option<Routine>Optional. The routine associated with the QueryTemplate.
create_time: Option<Timestamp>Output only. Timestamp when the QueryTemplate was created.
update_time: Option<Timestamp>Output only. Timestamp when the QueryTemplate was last modified.
Implementations
Sourceimpl QueryTemplate
impl QueryTemplate
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_proposer<T: Into<String>>(self, v: T) -> Self
pub fn set_proposer<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_primary_contact<T: Into<String>>(self, v: T) -> Self
pub fn set_primary_contact<T: Into<String>>(self, v: T) -> Self
Sets the value of primary_contact.
Example
let x = QueryTemplate::new().set_primary_contact("example");Sourcepub fn set_documentation<T: Into<String>>(self, v: T) -> Self
pub fn set_documentation<T: Into<String>>(self, v: T) -> Self
Sets the value of documentation.
Example
let x = QueryTemplate::new().set_documentation("example");Sourcepub fn set_routine<T>(self, v: T) -> Self
pub fn set_routine<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_routine<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_routine<T>(self, v: Option<T>) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = QueryTemplate::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = QueryTemplate::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = QueryTemplate::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = QueryTemplate::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = QueryTemplate::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = QueryTemplate::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for QueryTemplate
impl Clone for QueryTemplate
Sourcefn clone(&self) -> QueryTemplate
fn clone(&self) -> QueryTemplate
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for QueryTemplate
impl Debug for QueryTemplate
Sourceimpl Default for QueryTemplate
impl Default for QueryTemplate
Sourcefn default() -> QueryTemplate
fn default() -> QueryTemplate
Sourceimpl Message for QueryTemplate
impl Message for QueryTemplate
Sourceimpl PartialEq for QueryTemplate
impl PartialEq for QueryTemplate
impl StructuralPartialEq for QueryTemplate