BigQueryDatasetSource

Struct BigQueryDatasetSource 

#[non_exhaustive]
pub struct BigQueryDatasetSource { pub dataset: String, pub selected_resources: Vec<SelectedResource>, pub restricted_export_policy: Option<RestrictedExportPolicy>, pub replica_locations: Vec<String>, pub effective_replicas: Vec<Replica>, /* private fields */ }
A reference to a shared dataset. It is an existing BigQuery dataset with a collection of objects such as tables and views that you want to share with subscribers. When subscriber’s subscribe to a listing, Analytics Hub creates a linked dataset in the subscriber’s project. A Linked dataset is an opaque, read-only BigQuery dataset that serves as a symbolic link to a shared dataset.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
dataset: String

Optional. Resource name of the dataset source for this listing. e.g. projects/myproject/datasets/123

selected_resources: Vec<SelectedResource>

Optional. Resource in this dataset that is selectively shared. This field is required for data clean room exchanges.

restricted_export_policy: Option<RestrictedExportPolicy>

Optional. If set, restricted export policy will be propagated and enforced on the linked dataset.

replica_locations: Vec<String>

Optional. A list of regions where the publisher has created shared dataset replicas.

effective_replicas: Vec<Replica>

Output only. Server-owned effective state of replicas. Contains both primary and secondary replicas. Each replica includes a system-computed (output-only) state and primary designation.

Implementations

Source

impl BigQueryDatasetSource

pub fn new() -> Self

pub fn set_dataset<T: Into<String>>(self, v: T) -> Self

Sets the value of dataset.

Example
let x = BigQueryDatasetSource::new().set_dataset("example");
pub fn set_selected_resources<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<SelectedResource>,

Sets the value of selected_resources.

Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::SelectedResource;
let x = BigQueryDatasetSource::new()
    .set_selected_resources([
        SelectedResource::default()/* use setters */,
        SelectedResource::default()/* use (different) setters */,
    ]);
pub fn set_restricted_export_policy<T>(self, v: T) -> Self

Sets the value of restricted_export_policy.

Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::RestrictedExportPolicy;
let x = BigQueryDatasetSource::new().set_restricted_export_policy(RestrictedExportPolicy::default()/* use setters */);
pub fn set_or_clear_restricted_export_policy<T>(self, v: Option<T>) -> Self

Sets or clears the value of restricted_export_policy.

Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::RestrictedExportPolicy;
let x = BigQueryDatasetSource::new().set_or_clear_restricted_export_policy(Some(RestrictedExportPolicy::default()/* use setters */));
let x = BigQueryDatasetSource::new().set_or_clear_restricted_export_policy(None::<RestrictedExportPolicy>);
pub fn set_replica_locations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of replica_locations.

Example
let x = BigQueryDatasetSource::new().set_replica_locations(["a", "b", "c"]);
pub fn set_effective_replicas<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Replica>,

Sets the value of effective_replicas.

Example
use google_cloud_bigquery_analyticshub_v1::model::listing::big_query_dataset_source::Replica;
let x = BigQueryDatasetSource::new()
    .set_effective_replicas([
        Replica::default()/* use setters */,
        Replica::default()/* use (different) setters */,
    ]);