#[non_exhaustive]pub struct Listing {Show 19 fields
pub name: String,
pub display_name: String,
pub description: String,
pub primary_contact: String,
pub documentation: String,
pub state: State,
pub icon: Bytes,
pub data_provider: Option<DataProvider>,
pub categories: Vec<Category>,
pub publisher: Option<Publisher>,
pub request_access: String,
pub restricted_export_config: Option<RestrictedExportConfig>,
pub stored_procedure_config: Option<StoredProcedureConfig>,
pub discovery_type: Option<DiscoveryType>,
pub resource_type: SharedResourceType,
pub commercial_info: Option<CommercialInfo>,
pub log_linked_dataset_query_user_email: Option<bool>,
pub allow_only_metadata_sharing: Option<bool>,
pub source: Option<Source>,
/* private fields */
}Expand description
A listing is what gets published into a data exchange that a subscriber can subscribe to. It contains a reference to the data source along with descriptive information that will help subscribers find and subscribe the data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the listing.
e.g. projects/myproject/locations/us/dataExchanges/123/listings/456
display_name: StringRequired. Human-readable display name of the listing. The display name must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-), spaces ( ), ampersands (&) and can’t start or end with spaces. Default value is an empty string. Max length: 63 bytes.
description: StringOptional. Short description of the listing. The description must not contain Unicode non-characters and C0 and C1 control codes except tabs (HT), new lines (LF), carriage returns (CR), and page breaks (FF). Default value is an empty string. Max length: 2000 bytes.
primary_contact: StringOptional. Email or URL of the primary point of contact of the listing. Max Length: 1000 bytes.
documentation: StringOptional. Documentation describing the listing.
state: StateOutput only. Current state of the listing.
icon: BytesOptional. Base64 encoded image representing the listing. Max Size: 3.0MiB Expected image dimensions are 512x512 pixels, however the API only performs validation on size of the encoded data. Note: For byte fields, the contents of the field are base64-encoded (which increases the size of the data by 33-36%) when using JSON on the wire.
data_provider: Option<DataProvider>Optional. Details of the data provider who owns the source data.
categories: Vec<Category>Optional. Categories of the listing. Up to five categories are allowed.
publisher: Option<Publisher>Optional. Details of the publisher who owns the listing and who can share the source data.
request_access: StringOptional. Email or URL of the request access of the listing. Subscribers can use this reference to request access. Max Length: 1000 bytes.
restricted_export_config: Option<RestrictedExportConfig>Optional. If set, restricted export configuration will be propagated and enforced on the linked dataset.
stored_procedure_config: Option<StoredProcedureConfig>Optional. If set, stored procedure configuration will be propagated and enforced on the linked dataset.
discovery_type: Option<DiscoveryType>Optional. Type of discovery of the listing on the discovery page.
resource_type: SharedResourceTypeOutput only. Listing shared asset type.
commercial_info: Option<CommercialInfo>Output only. Commercial info contains the information about the commercial data products associated with the listing.
log_linked_dataset_query_user_email: Option<bool>Optional. By default, false. If true, the Listing has an email sharing mandate enabled.
allow_only_metadata_sharing: Option<bool>Optional. If true, the listing is only available to get the resource metadata. Listing is non subscribable.
source: Option<Source>Listing source.
Implementations
Sourceimpl Listing
impl Listing
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_primary_contact<T: Into<String>>(self, v: T) -> Self
pub fn set_primary_contact<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_documentation<T: Into<String>>(self, v: T) -> Self
pub fn set_documentation<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_data_provider<T>(self, v: T) -> Selfwhere
T: Into<DataProvider>,
pub fn set_data_provider<T>(self, v: T) -> Selfwhere
T: Into<DataProvider>,
Sets the value of data_provider.
Example
use google_cloud_bigquery_analyticshub_v1::model::DataProvider;
let x = Listing::new().set_data_provider(DataProvider::default()/* use setters */);Sourcepub fn set_or_clear_data_provider<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataProvider>,
pub fn set_or_clear_data_provider<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataProvider>,
Sets or clears the value of data_provider.
Example
use google_cloud_bigquery_analyticshub_v1::model::DataProvider;
let x = Listing::new().set_or_clear_data_provider(Some(DataProvider::default()/* use setters */));
let x = Listing::new().set_or_clear_data_provider(None::<DataProvider>);Sourcepub fn set_categories<T, V>(self, v: T) -> Self
pub fn set_categories<T, V>(self, v: T) -> Self
Sets the value of categories.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::Category;
let x = Listing::new().set_categories([
Category::Others,
Category::AdvertisingAndMarketing,
Category::Commerce,
]);Sourcepub fn set_publisher<T>(self, v: T) -> Self
pub fn set_publisher<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_publisher<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_publisher<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_access<T: Into<String>>(self, v: T) -> Self
pub fn set_request_access<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_restricted_export_config<T>(self, v: T) -> Selfwhere
T: Into<RestrictedExportConfig>,
pub fn set_restricted_export_config<T>(self, v: T) -> Selfwhere
T: Into<RestrictedExportConfig>,
Sets the value of restricted_export_config.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::RestrictedExportConfig;
let x = Listing::new().set_restricted_export_config(RestrictedExportConfig::default()/* use setters */);Sourcepub fn set_or_clear_restricted_export_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictedExportConfig>,
pub fn set_or_clear_restricted_export_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RestrictedExportConfig>,
Sets or clears the value of restricted_export_config.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::RestrictedExportConfig;
let x = Listing::new().set_or_clear_restricted_export_config(Some(RestrictedExportConfig::default()/* use setters */));
let x = Listing::new().set_or_clear_restricted_export_config(None::<RestrictedExportConfig>);Sourcepub fn set_stored_procedure_config<T>(self, v: T) -> Selfwhere
T: Into<StoredProcedureConfig>,
pub fn set_stored_procedure_config<T>(self, v: T) -> Selfwhere
T: Into<StoredProcedureConfig>,
Sets the value of stored_procedure_config.
Example
use google_cloud_bigquery_analyticshub_v1::model::StoredProcedureConfig;
let x = Listing::new().set_stored_procedure_config(StoredProcedureConfig::default()/* use setters */);Sourcepub fn set_or_clear_stored_procedure_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<StoredProcedureConfig>,
pub fn set_or_clear_stored_procedure_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<StoredProcedureConfig>,
Sets or clears the value of stored_procedure_config.
Example
use google_cloud_bigquery_analyticshub_v1::model::StoredProcedureConfig;
let x = Listing::new().set_or_clear_stored_procedure_config(Some(StoredProcedureConfig::default()/* use setters */));
let x = Listing::new().set_or_clear_stored_procedure_config(None::<StoredProcedureConfig>);Sourcepub fn set_discovery_type<T>(self, v: T) -> Selfwhere
T: Into<DiscoveryType>,
pub fn set_discovery_type<T>(self, v: T) -> Selfwhere
T: Into<DiscoveryType>,
Sets the value of discovery_type.
Example
use google_cloud_bigquery_analyticshub_v1::model::DiscoveryType;
let x0 = Listing::new().set_discovery_type(DiscoveryType::Private);
let x1 = Listing::new().set_discovery_type(DiscoveryType::Public);Sourcepub fn set_or_clear_discovery_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoveryType>,
pub fn set_or_clear_discovery_type<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoveryType>,
Sets or clears the value of discovery_type.
Example
use google_cloud_bigquery_analyticshub_v1::model::DiscoveryType;
let x0 = Listing::new().set_or_clear_discovery_type(Some(DiscoveryType::Private));
let x1 = Listing::new().set_or_clear_discovery_type(Some(DiscoveryType::Public));
let x_none = Listing::new().set_or_clear_discovery_type(None::<DiscoveryType>);Sourcepub fn set_resource_type<T: Into<SharedResourceType>>(self, v: T) -> Self
pub fn set_resource_type<T: Into<SharedResourceType>>(self, v: T) -> Self
Sets the value of resource_type.
Example
use google_cloud_bigquery_analyticshub_v1::model::SharedResourceType;
let x0 = Listing::new().set_resource_type(SharedResourceType::BigqueryDataset);
let x1 = Listing::new().set_resource_type(SharedResourceType::PubsubTopic);Sourcepub fn set_commercial_info<T>(self, v: T) -> Selfwhere
T: Into<CommercialInfo>,
pub fn set_commercial_info<T>(self, v: T) -> Selfwhere
T: Into<CommercialInfo>,
Sets the value of commercial_info.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::CommercialInfo;
let x = Listing::new().set_commercial_info(CommercialInfo::default()/* use setters */);Sourcepub fn set_or_clear_commercial_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommercialInfo>,
pub fn set_or_clear_commercial_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<CommercialInfo>,
Sets or clears the value of commercial_info.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::CommercialInfo;
let x = Listing::new().set_or_clear_commercial_info(Some(CommercialInfo::default()/* use setters */));
let x = Listing::new().set_or_clear_commercial_info(None::<CommercialInfo>);Sourcepub fn set_log_linked_dataset_query_user_email<T>(self, v: T) -> Self
pub fn set_log_linked_dataset_query_user_email<T>(self, v: T) -> Self
Sets the value of log_linked_dataset_query_user_email.
Example
let x = Listing::new().set_log_linked_dataset_query_user_email(true);Sourcepub fn set_or_clear_log_linked_dataset_query_user_email<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_log_linked_dataset_query_user_email<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of log_linked_dataset_query_user_email.
Example
let x = Listing::new().set_or_clear_log_linked_dataset_query_user_email(Some(false));
let x = Listing::new().set_or_clear_log_linked_dataset_query_user_email(None::<bool>);Sourcepub fn set_allow_only_metadata_sharing<T>(self, v: T) -> Self
pub fn set_allow_only_metadata_sharing<T>(self, v: T) -> Self
Sets the value of allow_only_metadata_sharing.
Example
let x = Listing::new().set_allow_only_metadata_sharing(true);Sourcepub fn set_or_clear_allow_only_metadata_sharing<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_allow_only_metadata_sharing<T>(self, v: Option<T>) -> Self
Sets or clears the value of allow_only_metadata_sharing.
Example
let x = Listing::new().set_or_clear_allow_only_metadata_sharing(Some(false));
let x = Listing::new().set_or_clear_allow_only_metadata_sharing(None::<bool>);Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::BigQueryDatasetSource;
let x = Listing::new().set_source(Some(
google_cloud_bigquery_analyticshub_v1::model::listing::Source::BigqueryDataset(BigQueryDatasetSource::default().into())));Sourcepub fn bigquery_dataset(&self) -> Option<&Box<BigQueryDatasetSource>>
pub fn bigquery_dataset(&self) -> Option<&Box<BigQueryDatasetSource>>
The value of source
if it holds a BigqueryDataset, None if the field is not set or
holds a different branch.
Sourcepub fn set_bigquery_dataset<T: Into<Box<BigQueryDatasetSource>>>(
self,
v: T,
) -> Self
pub fn set_bigquery_dataset<T: Into<Box<BigQueryDatasetSource>>>( self, v: T, ) -> Self
Sets the value of source
to hold a BigqueryDataset.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::BigQueryDatasetSource;
let x = Listing::new().set_bigquery_dataset(BigQueryDatasetSource::default()/* use setters */);
assert!(x.bigquery_dataset().is_some());
assert!(x.pubsub_topic().is_none());Sourcepub fn pubsub_topic(&self) -> Option<&Box<PubSubTopicSource>>
pub fn pubsub_topic(&self) -> Option<&Box<PubSubTopicSource>>
The value of source
if it holds a PubsubTopic, None if the field is not set or
holds a different branch.
Sourcepub fn set_pubsub_topic<T: Into<Box<PubSubTopicSource>>>(self, v: T) -> Self
pub fn set_pubsub_topic<T: Into<Box<PubSubTopicSource>>>(self, v: T) -> Self
Sets the value of source
to hold a PubsubTopic.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_bigquery_analyticshub_v1::model::listing::PubSubTopicSource;
let x = Listing::new().set_pubsub_topic(PubSubTopicSource::default()/* use setters */);
assert!(x.pubsub_topic().is_some());
assert!(x.bigquery_dataset().is_none());